import os
import json
import argparse

from jinja2 import Environment, FileSystemLoader
import importlib.resources as pkg_resources

def generate_index(folder_path: str) -> str:
    index_content = "<html><head><title>Talklink Index</title></head><body><h1>Talklink Index</h1><ul>"
    templates_path = os.path.join(pkg_resources.files('talklink'), 'resources/table_of_contents')
    env = Environment(loader=FileSystemLoader(templates_path))


    index_map = {}
    channelIdMap = {}
    for channel in os.listdir(folder_path):
        channel_path = os.path.join(folder_path, channel)
        if os.path.isdir(channel_path):
            index_map[channel] = {}
            for video_id in os.listdir(channel_path):
                video_path = os.path.join(channel_path, video_id)
                if os.path.isdir(video_path):
                    talklink_file = os.path.abspath(os.path.join(video_path, "talklink_page.html"))
                    if os.path.isfile(talklink_file):
                        video_info_file = os.path.join(video_path, "video_info.json")
                        if os.path.isfile(video_info_file):
                            with open(video_info_file, 'r') as f:
                                video_info = json.load(f)
                                title = video_info.get("title", video_id)
                                channel_id = video_info.get("channel_id", channel)
                        else:
                            title = video_id
                        
                        index_map[channel][video_id] = {
                            "id": video_id,
                            "title": title,
                            "talklink_file": talklink_file
                        }
                        channelIdMap[channel] = f"https://www.youtube.com/channel/{channel_id}"
    template = env.get_template('template.md')
    index_content = template.render(index_map=index_map, channelIdMap=channelIdMap)
    
    return index_content
if __name__ == "__main__":
    parser = argparse.ArgumentParser(description='Generate Talklink Index')
    parser.add_argument('--pages', type=str, help='Path to the folder containing channel data')  # Add argument for folder path
    parser.add_argument('--output', type=str, help='Path to the output file')
    args = parser.parse_args()  # Parse the arguments

    index = generate_index(args.pages)  # Use the folder path from arguments
    with open(args.output, "w") as index_file:
        index_file.write(index)